"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const content_disposition_parser_1 = __importDefault(require("content-disposition-parser"));
class MoreAppClient {
    client;
    constructor(options) {
        this.client = axios_1.default.create({
            ...options.axios,
            baseURL: options.prefix,
            headers: {
                ...options.axios?.headers,
                "X-More-Seal": options.seal,
                "User-Agent": `MoreApp NodeJS Client (${options.serviceName}) (https://moreapp.com)`,
            },
        });
    }
    async getBinary(path) {
        const response = await this.client.get(path, {
            responseType: "arraybuffer",
        });
        return {
            filename: getFilename(response),
            contentType: response.headers["content-type"] || "unknown",
            buffer: response.data,
        };
    }
    async get(path) {
        const response = await this.client.get(path, {
            responseType: "json",
        });
        return response.data;
    }
    async post(path, payload) {
        const response = await this.client.post(path, payload, {
            responseType: "json",
        });
        return response.data;
    }
    async delete(path) {
        const response = await this.client.delete(path, {
            responseType: "json",
        });
        return response.data;
    }
}
exports.default = MoreAppClient;
function getFilename(res) {
    const contentDispositionHeader = res.headers["content-disposition"];
    const filename = (0, content_disposition_parser_1.default)(contentDispositionHeader)?.filename;
    return filename ? decodeURI(filename) : undefined;
}
