"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const MoreAppClient_1 = __importDefault(require("./MoreAppClient"));
const nock_1 = __importDefault(require("nock"));
const axios_1 = require("axios");
test("download binary file", async () => {
    const file = Buffer.from("Some data");
    const apiMock = (0, nock_1.default)("https://api.moreapp.com")
        .get("/download")
        .matchHeader("x-more-seal", "my-seal")
        .reply(200, file, {
        "Content-Type": "image/jpg",
        "content-disposition": 'attachment; filename="my%20photo.jpg"',
    });
    const client = new MoreAppClient_1.default({
        serviceName: "Common Test",
        prefix: "https://api.moreapp.com",
        seal: "my-seal",
    });
    const binaryFile = await client.getBinary("/download");
    expect(binaryFile.buffer).toStrictEqual(file);
    expect(binaryFile.contentType).toBe("image/jpg");
    expect(binaryFile.filename).toBe("my photo.jpg");
    apiMock.done();
});
test("404", async () => {
    const apiMock = (0, nock_1.default)("https://api.moreapp.com").get("/download").reply(404);
    const client = new MoreAppClient_1.default({
        serviceName: "Common Test",
        prefix: "https://api.moreapp.com",
        seal: "my-seal",
    });
    await expect(client.getBinary("/download")).rejects.toStrictEqual(new axios_1.AxiosError("Request failed with status code 404"));
    apiMock.done();
});
test("unable to connect", async () => {
    const client = new MoreAppClient_1.default({
        serviceName: "Common Test",
        prefix: "https://non-existing.moreapp.com",
        seal: "my-seal",
    });
    await expect(client.getBinary("/download")).rejects.toThrowError("getaddrinfo ENOTFOUND non-existing.moreapp.com");
});
const client = new MoreAppClient_1.default({
    serviceName: "Common Test",
    prefix: "https://api.moreapp.com",
    seal: "my-seal",
});
test("Handle non existing file", async () => {
    const apiMock = (0, nock_1.default)("https://api.moreapp.com").get("/download").reply(404);
    await expect(client.getBinary("/download")).rejects.toThrow("Request failed with status code 404");
    apiMock.done();
});
test("Handle missing 'content-type' header", async () => {
    const apiMock = (0, nock_1.default)("https://api.moreapp.com").get("/download").reply(200);
    const binaryFile = await client.getBinary("/download");
    expect(binaryFile).not.toBeNull();
    expect(binaryFile.contentType).toBe("unknown");
    apiMock.done();
});
test("Handle missing 'content-disposition' header", async () => {
    const apiMock = (0, nock_1.default)("https://api.moreapp.com").get("/download").reply(200);
    const binaryFile = await client.getBinary("/download");
    expect(binaryFile).not.toBeNull();
    expect(binaryFile.filename).toBeUndefined();
    apiMock.done();
});
test("Handle invalid 'content-disposition' header", async () => {
    const apiMock = (0, nock_1.default)("https://api.moreapp.com").get("/download").reply(200, {}, {
        "content-disposition": "filename=my-photo.png",
    });
    const binaryFile = await client.getBinary("/download");
    expect(binaryFile).not.toBeNull();
    expect(binaryFile.filename).toBeUndefined();
    apiMock.done();
});
