"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatDateTime = exports.formatDate = exports.isDateTime = exports.isDate = void 0;
const date_and_time_1 = __importDefault(require("date-and-time"));
const DATE_REGEX = /^\d{4}-\d{1,2}-\d{1,2}$/;
const DATE_TIME_REGEX = /^\d{4}-\d{1,2}-\d{1,2} \d{1,2}:\d{2}$/;
function isDate(string) {
    return DATE_REGEX.test(string) && !isNaN(Date.parse(string));
}
exports.isDate = isDate;
function isDateTime(string) {
    return DATE_TIME_REGEX.test(string) && !isNaN(Date.parse(string));
}
exports.isDateTime = isDateTime;
function formatDate(dateString, format) {
    const date = date_and_time_1.default.parse(dateString, "YYYY-MM-DD");
    return date_and_time_1.default.format(date, formatDateFormat(format));
}
exports.formatDate = formatDate;
function formatDateTime(dateTime, format) {
    const date = typeof dateTime === "string"
        ? date_and_time_1.default.parse(dateTime, "YYYY-MM-DD HH:mm", true)
        : new Date(dateTime);
    return date_and_time_1.default.format(date, formatDateFormat(format) + " HH:mm", true);
}
exports.formatDateTime = formatDateTime;
function formatDateFormat(format) {
    switch (format) {
        case "DDMMYYYY":
            return "DD-MM-YYYY";
        case "MMDDYYYY":
            return "MM-DD-YYYY";
        case "YYYYMMDD":
            return "YYYY-MM-DD";
        default:
            return "DD-MM-YYYY";
    }
}
