"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dateUtil_1 = require("./dateUtil");
describe("isDate", () => {
    test("should handle valid dates", async () => {
        expect((0, dateUtil_1.isDate)("2020-01-01")).toBe(true);
        expect((0, dateUtil_1.isDate)("2020-1-1")).toBe(true);
        expect((0, dateUtil_1.isDate)("0000-1-1")).toBe(true);
    });
    test("should handle invalid dates", async () => {
        expect((0, dateUtil_1.isDate)("not-a-date")).toBe(false);
        expect((0, dateUtil_1.isDate)("3039-20-01")).toBe(false);
    });
});
describe("isDateTime", () => {
    test("should handle valid date times", async () => {
        expect((0, dateUtil_1.isDateTime)("2020-01-01 12:00")).toBe(true);
        expect((0, dateUtil_1.isDateTime)("2020-01-01 0:00")).toBe(true);
    });
    test("should handle invalid date times", async () => {
        expect((0, dateUtil_1.isDateTime)("2020-01-01 0:99")).toBe(false);
        expect((0, dateUtil_1.isDateTime)("2020-01-01 25:12")).toBe(false);
    });
});
describe("formatDate", () => {
    test("should format to given input", () => {
        expect((0, dateUtil_1.formatDate)("2022-02-18", "DDMMYYYY")).toBe("18-02-2022");
        expect((0, dateUtil_1.formatDate)("2022-02-18", "MMDDYYYY")).toBe("02-18-2022");
        expect((0, dateUtil_1.formatDate)("2022-02-18", "YYYYMMDD")).toBe("2022-02-18");
        expect((0, dateUtil_1.formatDate)("2022-02-18", "invalid")).toBe("18-02-2022");
    });
});
describe("formatDateTime", () => {
    test("should format to given input", () => {
        expect((0, dateUtil_1.formatDateTime)(1645191420000, "DDMMYYYY")).toBe("18-02-2022 13:37");
        expect((0, dateUtil_1.formatDateTime)("2022-02-18 13:37", "DDMMYYYY")).toBe("18-02-2022 13:37");
        expect((0, dateUtil_1.formatDateTime)("2022-02-18 13:37", "MMDDYYYY")).toBe("02-18-2022 13:37");
        expect((0, dateUtil_1.formatDateTime)("2022-02-18 13:37", "YYYYMMDD")).toBe("2022-02-18 13:37");
        expect((0, dateUtil_1.formatDateTime)("2022-02-18 13:37", "invalid")).toBe("18-02-2022 13:37");
    });
});
