"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatters = exports.logger = void 0;
const winston_1 = require("winston");
const entry_1 = require("@google-cloud/logging/build/src/entry");
const stackdriverTracingFormat = (0, winston_1.format)((info) => {
    if (info["trace_id"] && info["span_id"]) {
        info[entry_1.TRACE_KEY] = info["trace_id"];
        info[entry_1.SPAN_ID_KEY] = info["span_id"];
        info[entry_1.TRACE_SAMPLED_KEY] = true;
    }
    return info;
});
const errorFormat = (0, winston_1.format)((info) => {
    for (const prop in info) {
        if (info[prop] instanceof Error) {
            info[prop] = transformError(info[prop]);
        }
    }
    return info;
});
const transformError = (error) => {
    const transformed = {
        name: error.name,
        message: error.message,
    };
    if (error["cause"] !== undefined) {
        transformed["cause"] =
            error["cause"] instanceof Error ? transformError(error["cause"]) : error["cause"];
    }
    return transformed;
};
exports.logger = (0, winston_1.createLogger)({
    level: "info",
    transports: [new winston_1.transports.Console()],
    format: winston_1.format.combine(stackdriverTracingFormat(), errorFormat(), winston_1.format.json()),
});
exports.formatters = {
    errorFormat,
    stackdriverTracingFormat,
};
