"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("./logger");
describe("errorFormat", () => {
    test("should format standard errors", async () => {
        const error = new Error("Failed to persist");
        const formatted = logger_1.formatters
            .errorFormat()
            .transform({ level: "error", message: "Something went wrong", exception: error });
        expect(formatted).toStrictEqual({
            level: "error",
            message: "Something went wrong",
            exception: {
                name: "Error",
                message: "Failed to persist",
            },
        });
    });
    test("should format error with (deeply nested) cause", async () => {
        const error = new Error("Failed to persist", {
            cause: new Error("Caused by me!", { cause: "Well actually..." }),
        });
        const formatted = logger_1.formatters.errorFormat().transform({
            level: "error",
            message: "Something went wrong",
            exception: error,
        });
        expect(formatted).toStrictEqual({
            level: "error",
            message: "Something went wrong",
            exception: {
                name: "Error",
                message: "Failed to persist",
                cause: {
                    name: "Error",
                    message: "Caused by me!",
                    cause: "Well actually...",
                },
            },
        });
    });
});
describe("tracingFormat", () => {
    test("should transform tracing data to Stackdriver format", async () => {
        const formatted = logger_1.formatters.stackdriverTracingFormat().transform({
            level: "error",
            message: "Something went wrong",
            trace_id: "TRACE_ID",
            span_id: "SPAN_ID",
        });
        expect(formatted).toStrictEqual({
            level: "error",
            message: "Something went wrong",
            trace_id: "TRACE_ID",
            span_id: "SPAN_ID",
            "logging.googleapis.com/trace": "TRACE_ID",
            "logging.googleapis.com/spanId": "SPAN_ID",
            "logging.googleapis.com/trace_sampled": true,
        });
    });
});
