"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseIntegrationRequestSchema = exports.SubmissionSchema = exports.FormVersionSchema = exports.FormVersionFieldSchema = exports.EmailAddressSchema = void 0;
const zod_1 = require("zod");
const utils_1 = require("./utils");
exports.EmailAddressSchema = zod_1.z
    .string()
    .trim()
    .refine((val) => (0, utils_1.isValidEmail)(val));
exports.FormVersionFieldSchema = zod_1.z.object({
    uid: zod_1.z.string(),
    properties: zod_1.z.object({
        data_name: zod_1.z.string().optional(),
    }),
});
exports.FormVersionSchema = zod_1.z.object({
    fields: zod_1.z.array(exports.FormVersionFieldSchema),
});
exports.SubmissionSchema = zod_1.z.object({
    id: zod_1.z.string(),
    info: zod_1.z.object({
        customerId: zod_1.z.number(),
        formName: zod_1.z.string(),
        date: zod_1.z.number(),
        userId: zod_1.z.string(),
    }),
    meta: zod_1.z.object({
        registrationDate: zod_1.z.string(),
        instructionId: zod_1.z.string().nullable().optional().describe("DEPRECATED - Use 'taskId' instead"),
        taskId: zod_1.z.string().nullable(),
        serialNumber: zod_1.z.number(),
        guid: zod_1.z.string(),
        location: zod_1.z
            .object({
            longitude: zod_1.z.string(),
            latitude: zod_1.z.string(),
        })
            .nullable(),
    }),
    data: zod_1.z.record(zod_1.z.any()),
    mailStatuses: zod_1.z
        .array(zod_1.z.object({
        pdfFileId: zod_1.z.string().nullish(),
        emailAddresses: zod_1.z.array(exports.EmailAddressSchema),
    }))
        .nullish(),
});
exports.BaseIntegrationRequestSchema = zod_1.z.object({
    view: exports.FormVersionSchema,
    registration: exports.SubmissionSchema,
    seal: zod_1.z.string(),
    origin: zod_1.z.string(),
    settings: zod_1.z.object({
        dateFormat: zod_1.z.string(),
    }),
});
