"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDataForDataName = exports.parseDynamicRecipients = exports.isValidEmail = exports.currentTraceId = exports.environmentVariable = void 0;
const api_1 = require("@opentelemetry/api");
const lodash_1 = __importStar(require("lodash"));
function environmentVariable(key, fallback) {
    const value = process.env[key] || fallback;
    if (value === undefined) {
        throw new Error(`Missing environment variable '${key}'`);
    }
    else if (fallback === undefined) {
        return value;
    }
    else if (lodash_1.default.isString(fallback) && lodash_1.default.isString(value)) {
        return value;
    }
    else if (lodash_1.default.isFinite(fallback) && lodash_1.default.isFinite(Number(value))) {
        return Number(value);
    }
    else if (lodash_1.default.isBoolean(fallback) &&
        (lodash_1.default.isBoolean(value) || value === "true" || value === "false")) {
        return Boolean(value);
    }
    throw new Error(`Wrong type for environment variable '${key}'`);
}
exports.environmentVariable = environmentVariable;
function currentTraceId() {
    return api_1.trace.getSpanContext(api_1.context.active())?.traceId;
}
exports.currentTraceId = currentTraceId;
const emailAddressMaxLength = 254; // https://stackoverflow.com/a/574698
const emailAddressLocalPattern = /^.+$/;
const emailAddressDomainPattern = /^(?:[A-z0-9À-ž](?:[A-z0-9À-ž-]{0,61}[A-z0-9À-ž])?\.)+[A-z0-9À-ž][A-z0-9À-ž-]{0,61}[A-z0-9]$/;
// There are many regex patterns to validate email addresses, but they all have flaws and cannot 100% correctly verify
// every possible email address. For us, it's more important to avoid the majority of typo's instead of catching every
// invalid email address. We let our email provider handle and false positives (either by their validation or the fact
// that the email could not be delivered.
// ! This code is duplicated in other projects, make sure that changes are made there too (including tests).
function isValidEmail(email) {
    if (email.length > emailAddressMaxLength) {
        return false;
    }
    const [localAddr, domain, ...rest] = email.split("@");
    if (localAddr === undefined || domain === undefined || rest.length > 0) {
        return false;
    }
    return (!localAddr.startsWith(".") &&
        !localAddr.endsWith(".") &&
        !localAddr.includes(" ") &&
        emailAddressLocalPattern.test(localAddr) &&
        emailAddressDomainPattern.test(domain));
}
exports.isValidEmail = isValidEmail;
function parseDynamicRecipients(dynamicRecipients, fields, data) {
    const recipients = [];
    dynamicRecipients.forEach((fieldUid) => {
        if (!fieldUid) {
            return;
        }
        let dataName;
        if (fieldUid.includes(".")) {
            // column in Search-widget, like: "<field-uid>.email"
            const parts = fieldUid.split(".");
            dataName = [getDataNameForFieldUid(fields, parts[0]), parts[1]].join(".");
        }
        else {
            dataName = getDataNameForFieldUid(fields, fieldUid);
        }
        if (dataName) {
            const fieldData = getDataForDataName(data, dataName);
            if (fieldData && Array.isArray(fieldData)) {
                // like multiple Lookup-widget
                fieldData.forEach(function (dataFieldEntry) {
                    if (typeof dataFieldEntry === "string" && isValidEmail(dataFieldEntry.trim())) {
                        recipients.push(dataFieldEntry.trim());
                    }
                });
            }
            else if (typeof fieldData === "string" && isValidEmail(fieldData.trim())) {
                recipients.push(fieldData.trim());
            }
        }
    });
    return recipients;
}
exports.parseDynamicRecipients = parseDynamicRecipients;
function getDataNameForFieldUid(fields, fieldUid) {
    return fields.find((field) => field.uid === fieldUid)?.properties.data_name;
}
function getDataForDataName(data, dataName) {
    if (!dataName || !data) {
        return null;
    }
    // resolve nested field (like: SEARCH_FIELD.name)
    if (dataName.includes(".")) {
        const parts = dataName.split(".");
        let nestedData = data[parts[0]];
        if (isObject(nestedData)) {
            const nestedKey = parts.slice(1).join(".");
            return getDataForDataName(nestedData, nestedKey);
        }
    }
    return data[dataName];
}
exports.getDataForDataName = getDataForDataName;
function isObject(data) {
    return (0, lodash_1.isPlainObject)(data);
}
